#!/usr/bin/env python
#-*- coding: utf-8 -*-


import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk
from gi.repository import Gdk


import os
import sys
import time
import logging
from datetime import date


logger = logging.getLogger("Calendar")


class Calendar(Gtk.Calendar):
    def __init__(self):
        Gtk.Calendar.__init__(self)
        
    def get_datetime(self):
        logger.debug("get_datetime")
        year, month, day = self.get_date()
        month += 1
        mydate = date(year, month, day)
        return date(year, month, day)

        
    def get_real_date(self):
        year, month, day = self.get_date()
        month += 1
        logger.warning("return: %s", [year, month, day] )
        return [year, month, day]



try:
	from setuptools import setup, find_packages
except ImportError:
	from distutils.core import setup


try:
    import os
    here = os.path.abspath(os.path.dirname(__file__))
    README = open(os.path.join(here, 'README.rst')).read()
    CHANGES = open(os.path.join(here, 'CHANGES.rst')).read()
except:
    README = ''
    CHANGES = ''
    


setup(

	name         =   "mygtk",
	version      =   "0.0.4",
	py_modules   =   ["mygtk"],
    author       =   "oxidworks",
    author_email =   "apps@oxidworks.de",
    url          =   "https://oxidworks.de/",
    #download_url = 'https://github.com/oxidworks/ox_ebaysdk_settingseditor/tarball/0.2.5',
    description  =   "my personal gtk widget extensions",
    long_description = README + '\n\n' + CHANGES,

    packages     =   find_packages(),
    include_package_data = True,
    install_requires = [    
                            'wheel'           ],
    test_suite = 'nose.collector',
    tests_require = ['nose']
    )

